# Puppet module: autofs

This is a Puppet module for autofs based on the second generation layout ("NextGen") of Example42 Puppet Modules.

Made by Alessandro Franceschi / Lab42

Official site: http://www.example42.com

Official git repository: http://github.com/example42/puppet-autofs

Released under the terms of Apache 2 License.

This module requires functions provided by the Example42 Puppi module (you need it even if you don't use and install Puppi)

For detailed info about the logic and usage patterns of Example42 modules check the DOCS directory on Example42 main modules set.


## USAGE - Basic management

* Install autofs with default settings

        class { 'autofs': }

* Install a specific version of autofs package

        class { 'autofs':
          version => '1.0.1',
        }

* Disable autofs service.

        class { 'autofs':
          disable => true
        }

* Remove autofs package

        class { 'autofs':
          absent => true
        }

* Enable auditing without without making changes on existing autofs configuration *files*

        class { 'autofs':
          audit_only => true
        }

* Module dry-run: Do not make any change on *all* the resources provided by the module

        class { 'autofs':
          noops => true
        }


## USAGE - Overrides and Customizations
* Use custom sources for main config file 

        class { 'autofs':
          source => [ "puppet:///modules/example42/autofs/autofs.conf-${hostname}" , "puppet:///modules/example42/autofs/autofs.conf" ], 
        }


* Use custom source directory for the whole configuration dir

        class { 'autofs':
          source_dir       => 'puppet:///modules/example42/autofs/conf/',
          source_dir_purge => false, # Set to true to purge any existing file not present in $source_dir
        }

* Use custom template for main config file. Note that template and source arguments are alternative. 

        class { 'autofs':
          template => 'example42/autofs/autofs.conf.erb',
        }

* Automatically include a custom subclass

        class { 'autofs':
          my_class => 'example42::my_autofs',
        }


## USAGE - Example42 extensions management 
* Activate puppi (recommended, but disabled by default)

        class { 'autofs':
          puppi    => true,
        }

* Activate puppi and use a custom puppi_helper template (to be provided separately with a puppi::helper define ) to customize the output of puppi commands 

        class { 'autofs':
          puppi        => true,
          puppi_helper => 'myhelper', 
        }

* Activate automatic monitoring (recommended, but disabled by default). This option requires the usage of Example42 monitor and relevant monitor tools modules

        class { 'autofs':
          monitor      => true,
          monitor_tool => [ 'nagios' , 'monit' , 'munin' ],
        }

* Activate automatic firewalling. This option requires the usage of Example42 firewall and relevant firewall tools modules

        class { 'autofs':       
          firewall      => true,
          firewall_tool => 'iptables',
          firewall_src  => '10.42.0.0/24',
          firewall_dst  => $ipaddress_eth0,
        }


[![Build Status](https://travis-ci.org/example42/puppet-autofs.png?branch=master)](https://travis-ci.org/example42/puppet-autofs)
